#
# spec file for package soprano-backend-virtuoso
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           soprano-backend-virtuoso
Summary:        Virtuoso backend for Soprano
License:        GPL-2.0+
Group:          System/Libraries
# COMMON1-BEGIN
# COMMON1-BEGIN
Version:        2.9.4
Release:        5.4
Url:            http://soprano.sourceforge.net/
Source0:        http://downloads.sourceforge.net/soprano/soprano-%{version}.tar.bz2
Source100:      baselibs.conf
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  kde4-filesystem
BuildRequires:  libqt4-devel
BuildRequires:  libraptor-devel
BuildRequires:  librasqal-devel
BuildRequires:  libredland-devel
BuildRequires:  pkgconfig(libclucene-core)
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
# COMMON1-END
# COMMON1-END
BuildRequires:  libiodbc-devel
BuildRequires:  libsoprano-devel = %{version}
Requires:       libsoprano4 = %{version}
Requires:       virtuoso-server
Provides:       backend-virtuso = %{version}
Provides:       soprano_backend = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a Virtuoso based backend for Soprano.

%prep
# COMMON2-BEGIN
# COMMON2-BEGIN
%setup -q -n soprano-%{version}
# COMMON2-END
# COMMON2-END

%build
%cmake_kde4 -d build -- -DCMAKE_SKIP_RPATH=OFF -DBUILD_VIRTUOSO_BACKEND=ON
%make_jobs

%install
cd build
# this uses the cmake (mis)feature of 'make' building also the dependencies outside
# the directory and its subdirectories, 'make install' not installing them
cd backends/virtuoso
make DESTDIR=%{buildroot} install
cd ..

%if 0%{?suse_version}
%suse_update_desktop_file %{buildroot}%{_datadir}/soprano/plugins/virtuosobackend.desktop
%endif

%files
%defattr(-,root,root,-)
%{_libdir}/soprano/libsoprano_virtuosobackend.so
%{_datadir}/soprano/plugins/virtuosobackend.desktop

%changelog
* Wed Oct  9 2013 hrvoje.senjan@gmail.com
- Update to 2.9.4
  * Virtuoso Backend - Automatically delete faulty transaction logs
  * Virtuoso Backend supports parameterized queries which consume
    less memory when inserting large amounts of plain text
- Dropped 0001-VirtuosoBackend-Automatic-delete-faulty-transaction-log.patch
  merged upstream
- Added pkgconfig(libclucene-core) BuildRequires
* Fri Oct  4 2013 hrvoje.senjan@gmail.com
- Fix typo in previous patch, this made the patch useless
* Mon Sep 16 2013 hrvoje.senjan@gmail.com
- Added 0001-VirtuosoBackend-Automatic-delete-faulty-transaction-log.patch
  from upstream 2.9 branch, which resolves the situation when e.g.
  soprano log got corrupted, and that prevented nepomuk from opening
  the database
* Thu Jul 11 2013 cgiboudeaux@gmx.com
- Update to 2.9.3
  * Fix bugs in FilterModel
  * Optimize literal to N3 conversion
  * Virtuoso Backend - Optimize by around 5x
  * Fix potential memory leak in ErrorCache
* Thu Jun 13 2013 hrvoje.senjan@gmail.com
- Update to 2.9.2
  * Fix a crash in ServerCore on shutdown
  * Do no require X11 - not needed for compilation
  * Generate tag file for API docs
- Drop add-a-stop-method-which-closes-all-servers.patch, fix is
  included in this release
* Wed May  8 2013 hrvoje.senjan@gmail.com
- Revert add-a-stop-method-which-closes-all-servers.patch, as that
  commit uses method available only with future KDE 4.11, and breaks
  4.10
* Thu May  2 2013 hrvoje.senjan@gmail.com
- Update to 2.9.1
  * Faster streaming for datetime literals
  * Add a stop method in the LocalServer
  * Fixed bugs in LocalSocket and AsyncQuery
* Wed Jan  2 2013 hrvoje.senjan@gmail.com
- Update to 2.9.0
  * Better error handling on the Client::LocalSocketClient
  * New DataStream class which shares code between the server and client
  * New boolean option "emptyGraphs" in the Virtuoso backend, which can
    enable/disable checks for empty graphs
  * New boolean option "fakeBooleans" in the virtuoso backend, which can
    enable/disable fake boolean support
  * Client and Server code optimizations
- Drop no-qdebug-output-in-non-debug-modes.patch applied upstream
* Sun Nov 25 2012 hrvoje.senjan@gmail.com
- Added no-qdebug-output-in-non-debug-modes.patch from upstream,
  so soprano doesn't emmit qDebug output, fixes kde#247483
* Wed Nov 21 2012 cgiboudeaux@gmx.com
- Fix build on SLES (%%make_install is not expanded)
* Wed Jun 27 2012 toddrme2178@gmail.com
- Update to 2.8.0
  * Improved NRLModel query prefix expansion.
  * Support for plain SQL queries in the Virtuoso backend (required
  for improvements in Nepomuk).
  * Introduced new query language flag
    QueryLanguageSparqlNoInference. This language is not supported
    by any backends. It is supposed to be used in clients like
    Nepomuk to avoid the usage of long user types which are harder
    to read.
  * Convert Virtuoso IRI_ID values into simple literal strings. At
    some point if the need arises we might call ID_TO_IRI() to
    convert them into URIs.
  * New boolean option "noStatementSignals" in the Virtuoso backend
    which will disable Model::statementsAdded() and friends.
  * Improved local unix socket communication in the server/client
    system: A custom socket implementation as a replacment for
    QLocalSocket makes it possible to use one socket across threads
* Fri May 18 2012 Nico.Laus.2001@gmx.de
- Update to 2.7.6:
  * Support for the new SPARQL 1.1 DELETE statement which omits
    the graph to delete from for faster removeAllStatement
    execution in the Virtuoso backend.
  * Support for the new default graph query result format of
    Virtuoso >= 6.1.5.
  * Fixed apidox generation with Doxygen 1.8.0.
* Mon Mar  5 2012 asterios.dramis@gmail.com
- Update to 2.7.5:
  * Be less strict when converting a string to a QDateTime:
    + Allow an empty time part, ie. "2011-10-04".
    + Allow the usage of a space instead of "T" to separate date from time.
  * Fixed URI parsing in the SparqlModel.
  * Fixed an endless loop in the VirtuosoModel destruction which can happen in
    rare error cases.
  * Fixed serialization of non-string literal values.
  * Support Turtle result encoding in the SPARQL model.
* Sun Dec  4 2011 asterios.dramis@gmail.com
- Update to 2.7.4:
  * Enabled large file support (_FILE_OFFSET_BITS=64) to fix large DB file
    locking on 32bit machines.
  * Do not use an event loop when waiting for Virtuoso to initialize.
  * In the socket client: simply close the connection in case of a timeout. We
    cannot recover from it anyway.
* Tue Nov 15 2011 tittiatcoke@gmail.com
- Remove the build-require for CLucene-devel. The CLucene full
  text indexer is no longer used and has issues with newer versions
  of clucene-core.
* Sat Nov  5 2011 asterios.dramis@gmail.com
- Update to 2.7.3:
  * Added new signal in the Virtuoso backend which signals when the server goes
    down.
  * Soprano can be built with cmake 2.6.4 again.
- Removed 2_7_BRANCH.diff patch (included in the package).
* Wed Oct 26 2011 asterios.dramis@gmail.com
- Fix package licenses (bnc#726055).
* Tue Oct 25 2011 wstephenson@suse.com
- Add patch from 2.7 branch to allow clients to react in case of
  an unexpected Virtuoso server termination
* Sat Oct 22 2011 asterios.dramis@gmail.com
- Update to 2.7.2:
  * Reverted a change which was introduced in 2.7.1 to use a separate
    QDBusConnection for the DBusExportModel. It made things worse.
  * Fixed a crash in NRLModel caused by a non-mutex-protected hash.
  * Fixed the Virtuoso backend's option "forcedstart". Now the backend waits
    for the running instance to be shut down before trying to start a new one.
  From 2.7.1:
  * Lowered the min Raptor version to 2.0.0 since it was only a runtime
    dependancy for KDE.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to LGPL-2.0+.
  * Removed boost-devel and raptor from BuildRequires: (not needed).
* Mon Sep 19 2011 tittiatcoke@gmail.com
- Update to 2.7.0
  * Use the new Virtuoso parameter XAnyNormalization to use
    normalized accents for full-text searching by default.
  * Updated NAO Vocabulary namespace to include changes from
    SDO 0.7.
  * Added method LiteralValue::fromVariant which provides some
    useful type conversions.
  * Fixed incorrect binding names counting in redland queries.
  * Ported Raptor serializer and parser plugins to Raptor2.
* Thu Jul 21 2011 idonmez@novell.com
- Update to 2.6.51 needed for KDE 4.7rc2
* Mon May 16 2011 asterios.dramis@gmail.com
- Update to 2.6.0:
  * Fixed handling of xsd:boolean in SPARQL queries in the Virtuoso backend
    (this is a hack that might not work in all situations)
  * Added new parameter for the Virtuoso backend: QueryTimeout allows to set a
    maximum query exeution time.
  * Added new parameter for the Virtuoso backend: RestartOnCrash will restart
    the Virtuoso server if it crashes.
  * QueryResultIterator::next() now always returns false for boolean results.
    This breaks behaviour compared to previous versions. However, always
    returning true as before results in endless loops if the client does not
    check the type of the query result. Thus, in the interest of stability this
    change has been made anyway.
  * Lock the storage dir of a running virtuoso instance to avoid reusing it.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to LGPLv2+.
  * Updates in Summary, %%description and Group entries.
  * Added librasqal-devel in BuildRequires:.
  * Removed fdupes from BuildRequires: for sesame and virtuoso backends (not
    needed).
  * Minor other updates.
- Fixed rpmlint warning "untranslated-desktop-file".
* Tue Dec 14 2010 wstephenson@novell.com
- specfile cleanup: remove outdated versions and correct typos
* Fri Nov 19 2010 tittiatcoke@gmail.com
- update to 2.5.63
  * onto2vocabularyclass now extracts the nrl graph
  * Fixed default for ServerThreads parameter to match the docu
  * Additional settings to limit query time of Virtuoso
* Wed Oct  6 2010 coolo@novell.com
- update to 2.5.0:
  * New public qHash method for Statement
  * New Node::fromN3 method and operator>> which allows to
    parse nodes from N3 encoding.
  * Updated NRL ontology namespace
  * New operator== for BindingSet
  * Ported the DBus service watching to QDBusServiceWatcher
  * Highly improved server socket handling in the local and
    tcp socket server implementation.
  * Several improvements in the Virtuoso backend plugin.
* Wed Jul 28 2010 dmueller@suse.de
- update to 2.4.64:
  * beta release
  * more bugfixes over 2.4.63, no major changes
* Wed May  5 2010 tittiatcoke@gmail.com
- update to 2.4.63 (svn snapshot)
  * Added comparison operators for BindingSet
  * soprano prepared for wince
  * Slightly better way to detect graph query results
* Thu Apr 22 2010 tittiatcoke@gmail.com
- Update to 2.4.62 (svn snapshot)
  * qHash fix, as confirmed by thiago
  * Shut down Virtuoso using the SIGINT signal to make sure it does a checkpoint.
  * Allow to Build soprano with -fvisibility=hidden -fvisibility-inlines-hidden,
    patch by Modestas Vainius of Debian
  * Wait for the terminated virtuoso instance to be gone before continuing.
  * Use a portable include path: wait.h doesn't exist on BSD and Mac,
    sys/wait.h should be used instead.
  * Added pkgconfig files for sopranoclient, sopranoserver, and sopranoindex.
  * Check if we have a connection before attempting to send a command -> less crash.
  * Optimizations in the way the Qt sockets are created
  * Try to be compatible with Virtuoso 6.1.1 which renamed the results vars
* Wed Apr 21 2010 bitshuffler@opensuse.org
- Update to 2.4.2
  * LocalSocketClient and TcpClient: do not re-establish a
    connection on model deletion.
    (This fixes a crash when using a client as a global static)
  * Properly protect ErrorCache from multithread clashes.
    (Thanks to Andreas Hartmetz for the patch)
  * Slight optimizations in the Virtuoso backend.
  * Do not crash in ClientModel when the connection is lost.
* Tue Mar  9 2010 wstephenson@novell.com
-  Update to 2.4.1
  * Virtuoso backend improvements:
    o New parameter "forcedstart" which when set will make the
    backend shut down any running Virtuoso instance already
    accessing the storage dir (does not work on Windows).
    o Shut down Virtuoso using the SIGINT (instead of SIGTERM)
    signal to ensure a checkpoint (not available on Windows).
  * Allow to build Soprano with -fvisibility=hidden
  - fvisibility-inlines-hidden
  * New pkgConfig files for sopranoclient, sopranoserver, and
    sopranoindex.
* Thu Feb 11 2010 wstephenson@suse.de
- Update to 2.4.0.1
  * Fix threading error causing deadlocks (bko#226218, bko#226154)
* Thu Feb 11 2010 wstephenson@novell.com
- Update to 2.4.0
  * New methods Client::SparqlModel::listStatementsAsync and
    Client::SparqlModel::listContextsAsync.
  * Automatic query prefix expansion in NRLModel.
  * Automatic NRL metadata graph removal in NRLModel.
  * ServerCore is now fully multithreaded allowing two clients
    perform read-only commands simultaneously.
  * New Virtuoso storage backend which can either connect to a
    running Virtuoso instance or spawn one locally.
  * New convenience methods to handle BackendSettings.
  * New class AsyncQuery which will spawn a new thread for real
    asnycroneous query execution (in contrast to AsyncModel which
    only performs the actual query call in another thread while the
  iteration is synchronous).
  * Removed redland/librdf dependancy from raptor parser.
  * Sopranocmd improvements:
    o New paramter --nrl for sopranocmd which will trigger automatic
    query prefix expansion based on prefixes stored in the
    underlying model, automatic context creation for imported
    statements that do not have one set, and automatic meta
    data graph removal on removeContext calls.
    o New parameter --graphselect which allows to convert SPARQL
    select query results into a graph result. This is very usable
    since SPARQL construct queries do not support contexts/named graphs.
    o New command 'rmgraph' which allows to delete a list of graphs/contexts.
    o New parameter --foo which enables scriptable binding results
    without variable names.
* Sun Jan 31 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Jan  6 2010 dmueller@suse.de
- add dependency to virtuoso-server to virtuoso backend
* Sat Jan  2 2010 dmueller@suse.de
- fix build against redland 1.0.10
* Sat Dec 19 2009 dmueller@suse.de
- remove datadir.diff as it breaks the include detection
* Sat Dec 19 2009 llunak@novell.com
- add soprano-backend-redland to libsoprano-devel requires,
  as it is in practice needed by for building with soprano anyway
* Tue Dec 15 2009 dmueller@suse.de
- soprano now recommends virtuoso backend
* Tue Dec  1 2009 dmueller@suse.de
- updaet to 2.3.70 final
* Sat Nov 28 2009 tittiatcoke@gmail.com
- update to 2.3.70svn1055474
  * Improved documentation
  * Several Fixes for virtuoso
* Mon Nov 23 2009 tittiatcoke@gmail.com
- Update to 2.3.69svn1053174
  * Improved connection cleanup
  * Added maximum connection limit which allows to restrict the
    number of server threads.
  * Also find Virtuoso driver in special Virtuoso plugins installation
    dir as used by Mandriva (and possibly others)
* Thu Nov 19 2009 tittiatcoke@gmail.com
- Update to 2.3.67svn1051506
  * Enhancements to Virtuoso backend.
* Fri Nov 13 2009 dmueller@suse.de
- update to 2.3.1:
  * Changed installation path of cmake modules (SopranoAppOntology.cmake) to <prefix/share/soprano/cmake
  * Prevent the redland backend to add one statement multiple times.
  * Properly handle class names containing a dash '-' in onto2vocabularyclass
  * sopranocmd: Fail if trying to export a non-graph query
* Wed Sep  9 2009 dmueller@suse.de
- fix description of sesame package
- install Soprano cmake modules into a kde4 independent
  location
* Tue Aug 11 2009 llunak@suse.cz
- fix java requires ... again (bnc#461599)
* Wed Aug  5 2009 beineri@opensuse.org
- don't create soprano-backend-virtuoso.spec if it's not supposed
  to be built
* Wed Jul 22 2009 dmueller@suse.de
- update to 2.3.0:
  * http://soprano.sourceforge.net/node/35
* Wed Jun 24 2009 llunak@suse.cz
- require java-devel for sesame (bnc#461599)
* Wed Jun 24 2009 dmueller@suse.de
- update to 2.2.69:
  * Introduction of LanguageTag class
  * Support for plain RDF literals
* Mon May 11 2009 llunak@suse.cz
- build the Virtuoso backend separately
* Mon May 11 2009 llunak@suse.cz
- build also Virtuoso backend
* Mon May 11 2009 llunak@suse.cz
- update to 2.2.67:
  * new backend Virtuoso
* Fri Feb 27 2009 dmueller@suse.de
- update to 2.2.2:
  * Properly clear the error in the SparqlModel
  * Made all D-Bus dependant parts optional for successful compilation on Windows.
  * Redland include dir fix.
  * New cmake options to manually disable all optional components:
    o Redland backend
    o Sesame2 backend
    o Raptor parser/serializer
    o CLucene full text index
    o D-Bus integration
    o Apidox generation
  * Less use of dynamic_cast
* Thu Jan 22 2009 dmueller@suse.de
- update to 2.1.67:
  * New class Soprano::Client::SparqlModel which provides a client to http Sparql endpoints.
  * Added method Node::toN3 to easily build SPARQL queries without having to encode nodes all the time.
  * New convinience method QueryResultIterator::iterateStatementsFromBindings
  * Added convinience methods to handle BackendSettings.
  * Added operator[] to QueryResultIterator to easily access bindings
  * Added parameters influencing the visibility to onto2vocabularyclass
  * Soprano::Node now comes with definitions of qHash for both Node and QUrl
  * Sesame2 updated to 2.1.4
  * The IndexFilterModel can now optionally index specific URIs (IndexFilterModel::setForceIndexPredicates)
  * Added method IndexFilterModel::optimizeIndex which optimizes the clucene index on disk
  * Added method IndexFilterModel::encodeUriForLuceneQuery which encodes/escapes a URI so it can be used
  as a field in a clucene query.
  * SPARQL endpoint query support in sopranocmd
* Fri Jan  9 2009 dmueller@suse.de
- update to 2.1.64:
  * updated bindings for KDE 4.2
* Tue Oct 21 2008 dmueller@suse.de
- fix build for Qt 4.5 snapshots
* Tue Oct 14 2008 dmueller@suse.de
- correct spec file splitting again, was ordered incorrect
* Mon Oct 13 2008 dmueller@suse.de
- fix include handling for jni includes to fix ppc build
* Mon Sep 29 2008 dmueller@suse.de
- split sesame backend into seperate spec file to reduce build
  dependencies
* Mon Sep  8 2008 dmueller@suse.de
- fix build for old distros
* Thu Aug 28 2008 dmueller@suse.de
- add missing runtime dependency
* Wed Aug 27 2008 dmueller@suse.de
- update to 2.1.1:
  * http://soprano.sourceforge.net/node/26
* Wed Aug 27 2008 dmueller@suse.de
- need rpath for sesame2 backend
* Wed Jul 23 2008 dmueller@suse.de
- update to 2.1:
  * http://soprano.sourceforge.net/node/25
* Tue Jul 22 2008 dmueller@suse.de
- fix requires again
* Mon Jul 21 2008 dmueller@suse.de
- split backends into separate packages
* Sat Jul 19 2008 dmueller@suse.de
- compile for older distros
* Thu Jul 17 2008 dmueller@suse.de
- enable sesame2 backend
* Thu Apr 24 2008 dmueller@suse.de
- update to final 2.0.98 (alpha1) release
* Wed Apr 16 2008 dmueller@suse.de
- update to 2.0.98 to fix the communication issues
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Mar 31 2008 dmueller@suse.de
- update from SVN
* Tue Mar 25 2008 dmueller@suse.de
- update to 2.0.97:
  * new dbus interface
* Tue Mar 11 2008 dmueller@suse.de
- update to 2.0.3:
  * Fixed a string caching bug in LiteralValue which resulted in
  invalid string representations when assigning a QDate, QTime,
  QDateTime, or QByteArray via operator=
  * Use the CLucene StandardAnalyser by default instead of the
  SimpleAnalyser. This fixes indexing of numbers.
* Mon Feb 18 2008 dmueller@suse.de
- update to 2.0.2:
  * MutexModel in ReadWriteMultiThreading mode now allows multiple
  read operations from the same thread at the same time even if a
  write operation is waiting. This fixes a deadlock in the Nepomuk
  Strigi backend from KDE.
  * Fixed method statementCount in Sesame2 backend
  * Redland backend: Always encode strings as xls:string rather
  than rdfs:Literal values to match the Soprano guidelines.
  * Always set a dummy base URI in the raptor serializer
  * Fixed formatting of dateTime values.
  * Fixed NRL namespace
  * Fixed NAO namespace
  * Fixed plugin loading on MAC OS/X
* Wed Feb 13 2008 dmueller@suse.de
- fix devel package requires
* Mon Jan 14 2008 dmueller@suse.de
- fix lockfile generation
* Sat Jan 12 2008 stbinner@suse.de
- add version dependency on libsoprano4 (#353512)
* Mon Jan  7 2008 dmueller@suse.de
- update to 2.0.0 final:
  * Parser and serializer plugins for:
  - raptor (rdf+xml, turtle, trig, nTriples)
  - nQuads
  * Hierarchical architecture which allows to stack multiple
    filter models on top of an RDF storage.
* Thu Dec 20 2007 dmueller@suse.de
- update to svn750895:
  * API additions for better performance
* Tue Dec 18 2007 stbinner@suse.de
- fix plugin loading on 64bit architectures
* Sun Dec 16 2007 stbinner@suse.de
- readd redland as build requirement
* Mon Dec 10 2007 dmueller@suse.de
- update to 1.99 (rc2):
  * xesam interface, new ontology interface
* Tue Nov  6 2007 dmueller@suse.de
- update to 1.97.1 (beta4):
  * small API cleanup, more installed CamelCased headers
* Tue Nov  6 2007 dmueller@suse.de
- fix installation of index headers
* Tue Oct 30 2007 dmueller@suse.de
- enable cluclene based indexing backend
* Tue Oct 16 2007 dmueller@suse.de
- remove fdupes for older distributions
* Tue Oct  9 2007 dmueller@suse.de
- rename library package
* Tue Oct  9 2007 dmueller@suse.de
- update to 1.95.0-beta2:
  * removes redland dependency, uses raptor now directly
  * new query API
* Mon Sep  3 2007 schwab@suse.de
- Fix broken compiler flags.
* Fri Jun  1 2007 dmueller@suse.de
- update to 0.9.0:
  * crash fix
* Fri May 11 2007 dmueller@suse.de
- update to current SVN:
  * small API change
* Fri May  4 2007 dmueller@suse.de
- update to 3.90.1:
  * no actual code change
- fix packaging to match Library Policy
* Thu May  3 2007 dmueller@suse.de
- adapt libredland-devel rename
* Wed May  2 2007 dmueller@suse.de
- Initial package (trunk SVN)
